==> group_subscription-2.0.0-alpha3.tar.gz: group_subscription/src/Plugin/QueueWorker/ImmediateEmailBase.php <==
<?php

/**
 * @file
 * Contains Drupal\group_subscription\Plugin\QueueWorker\ImmediateEmailBase.php
 */

namespace Drupal\group_subscription\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\Mail\MailManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Render\RendererInterface;

if (!defined('GROUP_SUBSCRIPTION_TYPE_DISABLED')) {
  define('GROUP_SUBSCRIPTION_TYPE_DISABLED', 0);
}

if (!defined('GROUP_SUBSCRIPTION_TYPE_IMMEDIATE')) {
  define('GROUP_SUBSCRIPTION_TYPE_IMMEDIATE', 1);
}

if (!defined('GROUP_SUBSCRIPTION_TYPE_DAILY')) {
  define('GROUP_SUBSCRIPTION_TYPE_DAILY', 2);
}

/**
 * Provides base functionality for the Immediate Email Queue Workers.
 */
abstract class ImmediateEmailBase extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
  * The mail manager.
  *
  * @var Drupal\Core\Mail\MailManager
  */
  protected $mail;

  /**
   * The user storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $userStorage;

  /**
   * The node storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The comment storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $commentStorage;

  /**
   * The group storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $groupStorage;

  /**
   * The theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected $themeManager;

  /**
   * The renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * {@inheritdoc}
   */
  public function __construct(
      MailManager $mail,
      EntityStorageInterface $user_storage,
      EntityStorageInterface $node_storage,
      EntityStorageInterface $comment_storage,
      EntityStorageInterface $group_storage,
      ThemeManagerInterface $theme_manager,
      RendererInterface $renderer
  ) {
    $this->mail = $mail;
    $this->userStorage = $user_storage;
    $this->nodeStorage = $node_storage;
    $this->commentStorage = $comment_storage;
    $this->groupStorage = $group_storage;
    $this->themeManager = $theme_manager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $container->get('plugin.manager.mail'),
      $container->get('entity.manager')->getStorage('user'),
      $container->get('entity.manager')->getStorage('node'),
      $container->get('entity.manager')->getStorage('comment'),
      $container->get('entity.manager')->getStorage('group'),
      $container->get('theme.manager'),
      $container->get('renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $protoemail = $data;

    // Check the master switch and account status for the recipient.
    $query = \Drupal::database()->select('group_subscription_global', 'g');
    $query->join('users_field_data', 'f', 'g.uid = f.uid');
    $query->fields('g', ['uid'])
      ->condition('g.uid', $protoemail->uid)
      ->condition('g.status', 1)
      ->condition('f.status', 1);

    $user = $query->execute()->fetchField();
    if ($user) {
      // Build and send this email.
      $this->sendImmediateEmail($protoemail);
    }

  }

  /**
   * Convert this protoemail into an actual email message and send it.
   *
   * @return int
   */
  protected function sendImmediateEmail($protoemail) {
    $params = [];

    // Load the subscribed user object to serve as the email recipient.
    $uid = $protoemail->uid;
    $user = $this->userStorage->load($uid);

    // User values for email settings.
    $email = $user->getEmail();
    $username = $user->getDisplayName();
    $langcode = $user->getPreferredLangcode();

    // Set recipient display name.
    $params['recipient'] = $username;

    // Load the subscribed group object.
    $gid = $protoemail->gid;
    $group = $this->groupStorage->load($gid);
    if (is_null($group)) {
      // This group entity does not exist.
      return;
    }
    $group_name = $group->get('label')->value;

    // Get entity information so we can determine how to load the entity.
    $entityid = $protoemail->entityid;
    $entitytype = $protoemail->entitytype;
    $bundle = $protoemail->bundle;

    // Determine which theme we should use to render these items.
    $config = \Drupal::config('system.theme');
    $default_theme = $config->get('default');
    $this->themeManager->setActiveTheme(\Drupal::service('theme.initialization')->initTheme($default_theme));

    // Build the email based on the type of entity we're working with.
    if ($entitytype === 'node') {
      $entity = $this->nodeStorage->load($entityid);
      if (is_null($entity)) {
        // This node entity does not exist.
        return;
      }
      $author = $entity->getOwner();

      // Add email subject line.
      $params['subject'] = t('@group_name: New @bundle: @title by @author',
        ['@group_name' => $group_name,
          '@title' => $entity->getTitle(),
          '@bundle' => $bundle,
          '@author' => $author->getDisplayName(),
        ]);

      $params['author'] = $author->getDisplayName();
      $params['group_name'] = $group_name;
      $params['bundle'] = $bundle;

      // Render the content using group_subscription_immediate display.
      $content = \Drupal::entityTypeManager()
        ->getViewBuilder($entity->getEntityTypeId())
        ->view($entity, 'group_subscription_immediate');
      $params['content'] = $this->renderer->renderRoot($content);
      // TODO: fix to use proper dependency injection.

      $params['link'] = $entity
        ->toLink(NULL, 'canonical', ['absolute' => TRUE])
        ->setText(t('View @bundle', ['@bundle' => $bundle]))
        ->toString();

      // See hook_mail() implementation in group_subscription.module.
      $this->mail->mail(
        'group_subscription',
        'immediate_content',
        $email,
        $langcode ?: 'en',
        $params,
        NULL,
        TRUE
      );

    }
    elseif ($entitytype === 'comment') {
      $entity = $this->commentStorage->load($entityid);
      if (is_null($entity)) {
        // This comment entity does not exist.
        return;
      }
      $author = $entity->getOwner();

      // Comments must be attached to a parent entity, load that information.
      $parentid = $protoemail->parentid;
      $parenttype = $protoemail->parenttype;

      if ($parenttype === 'node') {
        $parententity = $this->nodeStorage->load($parentid);
        $parentauthor = $parententity->getOwner()->getDisplayName();
        $parent_bundle = $parententity->type->entity->label();
        $parent_title = $parententity->getTitle();
        // TODO: load parent bundle proper name.
        // $parent_bundle = NodeType::load($parent_bundle)->get('name');
      }
      else {
        // TODO: expand to support comments on entities other than nodes.
        return;
      }

      // Add email subject line.
      $params['subject'] = t('@group_name: New Comment on @title by @comment_author',
        ['@group_name' => $group_name,
          '@title' => $parententity->getTitle(),
          '@comment_author' => $author->getDisplayName(),
        ]);

      $params['group_name'] = $group_name;
      $params['parent_author'] = $parentauthor;
      $params['parent_type'] = $parent_bundle;
      $params['parent_title'] = $parent_title;

      // Render the parent content using group_subscription_immediate display.
      $parent_content = \Drupal::entityTypeManager()
        ->getViewBuilder($parententity->getEntityTypeId())
        ->view($parententity, 'group_subscription_immediate');
      $params['parent_content'] = $this->renderer->renderRoot($parent_content);
      // TODO: fix to use proper dependency injection.

      // Render the comment using group_subscription_immediate display.
      $comment_content = \Drupal::entityTypeManager()
        ->getViewBuilder($entity
        ->getEntityTypeId())
        ->view($entity, 'group_subscription_immediate');
      $params['comment_content'] = $this->renderer->renderRoot($comment_content);
      // TODO: fix to use proper dependency injection.

      $params['comment_subject'] = $entity->getSubject();
      $params['comment_author'] = $author->getDisplayName();

      $params['link'] = $parententity
        ->toLink(NULL, 'canonical', ['absolute' => TRUE])
        ->setText(t('View @parent_type', ['@parent_type' => $parent_bundle]))
        ->toString();

      // See hook_mail() implementation in group_subscription.module.
      $this->mail->mail(
        'group_subscription',
        'immediate_comment',
        $email,
        $langcode ?: 'en',
        $params,
        NULL,
        TRUE
      );

    }
    else {
      // TODO: expand to support emails for entities other than nodes.
      return;
    }

  }

}

==> group_subscription-3.0.0-alpha3.tar.gz: group_subscription/src/Plugin/QueueWorker/ImmediateEmailBase.php <==
<?php

namespace Drupal\group_subscription\Plugin\QueueWorker;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\Mail\MailManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

if (!defined('GROUP_SUBSCRIPTION_TYPE_DISABLED')) {
  define('GROUP_SUBSCRIPTION_TYPE_DISABLED', 0);
}

if (!defined('GROUP_SUBSCRIPTION_TYPE_IMMEDIATE')) {
  define('GROUP_SUBSCRIPTION_TYPE_IMMEDIATE', 1);
}

if (!defined('GROUP_SUBSCRIPTION_TYPE_DAILY')) {
  define('GROUP_SUBSCRIPTION_TYPE_DAILY', 2);
}

/**
 * Provides base functionality for the Immediate Email Queue Workers.
 */
abstract class ImmediateEmailBase extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The mail manager.
   *
   * @var Drupal\Core\Mail\MailManager
   */
  protected $mail;

  /**
   * The user storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $userStorage;

  /**
   * The node storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * The comment storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $commentStorage;

  /**
   * The group storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $groupStorage;

  /**
   * The theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected $themeManager;

  /**
   * The renderer.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * {@inheritdoc}
   */
  public function __construct(
      MailManager $mail,
      EntityStorageInterface $user_storage,
      EntityStorageInterface $node_storage,
      EntityStorageInterface $comment_storage,
      EntityStorageInterface $group_storage,
      ThemeManagerInterface $theme_manager,
      RendererInterface $renderer
  ) {
    $this->mail = $mail;
    $this->userStorage = $user_storage;
    $this->nodeStorage = $node_storage;
    $this->commentStorage = $comment_storage;
    $this->groupStorage = $group_storage;
    $this->themeManager = $theme_manager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $container->get('plugin.manager.mail'),
      $container->get('entity_type.manager')->getStorage('user'),
      $container->get('entity_type.manager')->getStorage('node'),
      $container->get('entity_type.manager')->getStorage('comment'),
      $container->get('entity_type.manager')->getStorage('group'),
      $container->get('theme.manager'),
      $container->get('renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $protoemail = $data;

    // Check the master switch and account status for the recipient.
    $query = \Drupal::database()->select('group_subscription_global', 'g');
    $query->join('users_field_data', 'f', 'g.uid = f.uid');
    $query->fields('g', ['uid'])
      ->condition('g.uid', $protoemail->uid)
      ->condition('g.status', 1)
      ->condition('f.status', 1);

    $user = $query->execute()->fetchField();
    if ($user) {
      // Build and send this email.
      $this->sendImmediateEmail($protoemail);
    }

  }

  /**
   * Convert this protoemail into an actual email message and send it.
   */
  protected function sendImmediateEmail($protoemail) {
    $params = [];

    // Load the subscribed user object to serve as the email recipient.
    $uid = $protoemail->uid;
    $user = $this->userStorage->load($uid);

    // User values for email settings.
    $email = $user->getEmail();
    $username = $user->getDisplayName();
    $langcode = $user->getPreferredLangcode();

    // Set recipient display name.
    $params['recipient'] = $username;

    // Load the subscribed group object.
    $gid = $protoemail->gid;
    $group = $this->groupStorage->load($gid);
    if (is_null($group)) {
      // This group entity does not exist.
      return;
    }
    $group_name = $group->get('label')->value;

    // Get entity information so we can determine how to load the entity.
    $entityid = $protoemail->entityid;
    $entitytype = $protoemail->entitytype;
    $bundle = $protoemail->bundle;

    // Determine which theme we should use to render these items.
    $config = \Drupal::config('system.theme');
    $default_theme = $config->get('default');
    $this->themeManager->setActiveTheme(\Drupal::service('theme.initialization')->initTheme($default_theme));

    // Build the email based on the type of entity we're working with.
    if ($entitytype === 'node') {
      $entity = $this->nodeStorage->load($entityid);
      if (is_null($entity)) {
        // This node entity does not exist.
        return;
      }
      $author = $entity->getOwner();

      // Add email subject line.
      $params['subject'] = $this->t('@group_name: New @bundle: @title by @author',
        [
          '@group_name' => $group_name,
          '@title' => $entity->getTitle(),
          '@bundle' => $bundle,
          '@author' => $author->getDisplayName(),
        ]);

      $params['author'] = $author->getDisplayName();
      $params['group_name'] = $group_name;
      $params['bundle'] = $bundle;

      // Render the content using group_subscription_immediate display.
      // TODO: fix to use proper dependency injection.
      $content = \Drupal::entityTypeManager()
        ->getViewBuilder($entity->getEntityTypeId())
        ->view($entity, 'group_subscription_immediate');
      $params['content'] = $this->renderer->renderRoot($content);

      $params['link'] = $entity
        ->toLink(NULL, 'canonical', ['absolute' => TRUE])
        ->setText($this->t('View @bundle', ['@bundle' => $bundle]))
        ->toString();

      // See hook_mail() implementation in group_subscription.module.
      $this->mail->mail(
        'group_subscription',
        'immediate_content',
        $email,
        $langcode ?: 'en',
        $params,
        NULL,
        TRUE
      );

    }
    elseif ($entitytype === 'comment') {
      $entity = $this->commentStorage->load($entityid);
      if (is_null($entity)) {
        // This comment entity does not exist.
        return;
      }
      $author = $entity->getOwner();

      // Comments must be attached to a parent entity, load that information.
      $parentid = $protoemail->parentid;
      $parenttype = $protoemail->parenttype;

      if ($parenttype === 'node') {
        $parententity = $this->nodeStorage->load($parentid);
        $parentauthor = $parententity->getOwner()->getDisplayName();
        $parent_bundle = $parententity->type->entity->label();
        $parent_title = $parententity->getTitle();
        // TODO: load parent bundle proper name.
        // $parent_bundle = NodeType::load($parent_bundle)->get('name');
      }
      else {
        // TODO: expand to support comments on entities other than nodes.
        return;
      }

      // Add email subject line.
      $params['subject'] = $this->t('@group_name: New Comment on @title by @comment_author',
        [
          '@group_name' => $group_name,
          '@title' => $parententity->getTitle(),
          '@comment_author' => $author->getDisplayName(),
        ]);

      $params['group_name'] = $group_name;
      $params['parent_author'] = $parentauthor;
      $params['parent_type'] = $parent_bundle;
      $params['parent_title'] = $parent_title;

      // Render the parent content using group_subscription_immediate display.
      // TODO: fix to use proper dependency injection.
      $parent_content = \Drupal::entityTypeManager()
        ->getViewBuilder($parententity->getEntityTypeId())
        ->view($parententity, 'group_subscription_immediate');
      $params['parent_content'] = $this->renderer->renderRoot($parent_content);

      // Render the comment using group_subscription_immediate display.
      // TODO: fix to use proper dependency injection.
      $comment_content = \Drupal::entityTypeManager()
        ->getViewBuilder($entity->getEntityTypeId())
        ->view($entity, 'group_subscription_immediate');
      $params['comment_content'] = $this->renderer->renderRoot($comment_content);

      $params['comment_subject'] = $entity->getSubject();
      $params['comment_author'] = $author->getDisplayName();

      $params['link'] = $parententity
        ->toLink(NULL, 'canonical', ['absolute' => TRUE])
        ->setText($this->t('View @parent_type', ['@parent_type' => $parent_bundle]))
        ->toString();

      // See hook_mail() implementation in group_subscription.module.
      $this->mail->mail(
        'group_subscription',
        'immediate_comment',
        $email,
        $langcode ?: 'en',
        $params,
        NULL,
        TRUE
      );

    }
    else {
      // TODO: expand to support emails for entities other than nodes.
      return;
    }

  }

}
